@@ -183,25 +183,26 @@ class ForeignKey:
 
 class Relation:
 
-    def __init__(self, foreign_model, name=None, print_options=None):
+    def __init__(self, foreign_model, name=None, print_options=None, lazy_load=True):
         self.foreign_model = foreign_model
         self.name = name
         self.print_options = print_options
+        self.lazy_load = lazy_load
 
 
 class ManyToOne(Relation):
 
     def __init__(self, foreign_model, foreign_key_field,
-                 foreign_model_key_field=None, update_search_column=None,
+                 foreign_model_key_field=None, insert_search_column=None, update_search_column=None,
                  load_all=False, lazy_load=True, name=None, print_options=None):
-        super().__init__(foreign_model=foreign_model, name=name, print_options=print_options)
+        super().__init__(foreign_model=foreign_model, name=name, print_options=print_options, lazy_load=lazy_load)
         self.foreign_key_field = foreign_key_field
         if foreign_model_key_field is None:
             self.foreign_model_key_field = self.foreign_key_field
         else:
             self.foreign_model_key_field = foreign_model_key_field
+        self.insert_search_column = insert_search_column
         self.update_search_column = update_search_column
-        self.lazy_load = lazy_load
         self.load_all = load_all
         self._entity = None
 
@@ -238,10 +239,9 @@ class ManyToMany(Relation):
     def __init__(self, foreign_model, junction_table,
                  foreign_key_field, lazy_load=True, aggregation=None,
                  name=None, print_options=None):
-        super().__init__(foreign_model=foreign_model, name=name, print_options=print_options)
+        super().__init__(foreign_model=foreign_model, name=name, print_options=print_options, lazy_load=lazy_load)
         self.foreign_key_field = foreign_key_field
         self.junction_table = TableName.build(junction_table)
-        self.lazy_load = lazy_load
         self.aggregation = aggregation
         self._entities = None
         self._aggregation_value = None
@@ -288,8 +288,7 @@ class ManyToMany(Relation):
 class OneToMany(Relation):
 
     def __init__(self, foreign_model, lazy_load=True, aggregation=None, name=None, print_options=None):
-        super().__init__(foreign_model=foreign_model, name=name, print_options=print_options)
-        self.lazy_load = lazy_load
+        super().__init__(foreign_model=foreign_model, name=name, print_options=print_options, lazy_load=lazy_load)
         self.aggregation = aggregation
         self._entities = None
         self._aggregation_value = None
