@@ -93,7 +93,7 @@ class QueryWizzard:
         self.models[key] = model_cls_meta.class_reference
         # print('register_model:', key)
 
-    def get_model(self, model) -> Type[Model]:
+    def get_model(self, model: Type[Model] or str) -> Type[Model]:
         if isinstance(model, str):
             try:
                 return self.models[model]
@@ -720,6 +720,7 @@ class QueryWizzard:
 
     def retrieve_id_by_value(self, model, filter_column, filter_value):
         model = self.get_model(model)
+
         id_ = self.retrieve_value_by_value(
             model=model,
             lookup_column=model.id_field_name(),
@@ -829,15 +830,18 @@ class QueryWizzard:
                     )
         return related_queries
 
-    def get_m21_value(self, relation, value):
+    def get_m21_value(self, relation, filter_column, value):
         if relation.load_all:
             return int(value)
         else:
-            return self.retrieve_id_by_value(
-                model=relation.foreign_model,
-                filter_column=relation.update_search_column,
-                filter_value=value
-            )
+            if filter_column:
+                return self.retrieve_id_by_value(
+                    model=relation.foreign_model,
+                    filter_column=filter_column,
+                    filter_value=value
+                )
+            else:
+                return value
 
     def insert_query(self, model, data):
         # todo: refactor: put on merge query builder?
@@ -850,7 +854,7 @@ class QueryWizzard:
                     continue
                 relation = model.get_relation(column)
                 if isinstance(relation, ManyToOne):
-                    fk_id = self.get_m21_value(relation, value)
+                    fk_id = self.get_m21_value(relation, relation.insert_search_column, value)
                     if fk_id:
                         inserts[relation.foreign_key_field] = fk_id
             else:
@@ -909,6 +913,7 @@ class QueryWizzard:
         return inserted_id
 
     def execute_insert(self, model, data, insert_query):
+        print(insert_query)
         self.execute_query(insert_query)
         inserted_id = self.last_insert_rowid()
 
@@ -922,7 +927,9 @@ class QueryWizzard:
 
         return inserted_id
 
-    def create(self, model, data, return_created_object=True, commit=True):
+    def create(self, model: Type[Model] or str, data, return_created_object=True, commit=True) -> dict or int:
+        if not data:
+            raise ValueError('Invalid argument data: should not be empty')
         model = self.get_model(model)
         insert_query = self.insert_query(model, data)
         try:
@@ -938,7 +945,7 @@ class QueryWizzard:
             return self.get_by_id(model, inserted_id, entity_format=EntityFormat.JSON)
         return inserted_id
 
-    def update(self, model, filter_condition, instance_id, prev_data, data, fetch_m21_values=False):
+    def update(self, model, filter_condition, instance_id, prev_data, data):
         # todo only update changed data
         # i.e. difference data - instance.data
         # todo: what about commit?
@@ -957,12 +964,8 @@ class QueryWizzard:
 
             relation = model.get_relation(column)
 
-            # todo: refactor
             if isinstance(relation, ManyToOne):
-                if fetch_m21_values:
-                    fk_id = self.get_m21_value(relation, value)
-                else:
-                    fk_id = value
+                fk_id = self.get_m21_value(relation, relation.update_search_column, value)
                 if fk_id:
                     updates[relation.foreign_key_field] = fk_id
 
